@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.h 550 2005-09-01 07:23:16Z svn $
+ * $Id: Auxiliary.h 674 2005-09-13 18:31:36Z svn $
  *****************************************************************************/
 
 #ifndef AUXILIARY_H
@@ -36,7 +36,6 @@
 #endif
 
 #include "apr_pools.h"
-#include "apr_time.h"
 
 #include <stdlib.h>
 
@@ -47,7 +46,6 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-apr_time_t mtime(apr_pool_t *pool, const char *path);
 const char *rfc1738_encode(apr_pool_t *pool, const char* str);
 const char *size_str(apr_pool_t *pool, apr_uint64_t size);
 const char *comma_str(apr_pool_t *pool, apr_size_t number);
