@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 547 2005-08-31 19:53:30Z svn $
+ * $Id: UploadItem.h 684 2005-09-15 07:12:00Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEM_H
@@ -50,13 +50,15 @@ class UploadItem
     friend class UploadItemCreator;
 
 public:
-    static const apr_size_t MAX_VERSION_LENGTH          = 8;
+    static const apr_size_t MAX_IDENTIFIER_LENGTH       = 16;
+    static const apr_size_t MAX_VERSION_LENGTH          = 16;
     static const apr_size_t MAX_FILE_MIME_LENGTH        = 64;
     static const apr_size_t MAX_FILE_NAME_LENGTH        = 64;
+    static const apr_size_t MAX_FILE_DIGEST_LENGTH      = 48;
     static const apr_size_t MAX_REMOVE_PASS_LENGTH      = 16;
     static const apr_size_t MAX_DOWNLOAD_PASS_LENGTH    = 16;
     static const apr_size_t MAX_COMMENT_LENGTH          = 256;
-    static const apr_size_t ITEM_HEADER_SIZE            = 512; // ;͵Ƥ
+    static const apr_size_t ITEM_HEADER_SIZE            = 640; // ;͵Ƥ
 
     static const char FILE_PARAM[];
     static const char COMMENT_PARAM[];
@@ -67,17 +69,24 @@ public:
     typedef struct Header {
         union {
             struct {
-                char        identifier[(sizeof(PACKAGE_NAME)/4 + 1)*4];
+                char        identifier[MAX_IDENTIFIER_LENGTH];
                 char        version[MAX_VERSION_LENGTH];
-                apr_size_t  file_size;
-                apr_time_t  time;
+                union {
+                    apr_size_t  file_size;
+                    char        dummy_file_size[16];
+                };
+                union {
+                    apr_time_t  time;
+                    char        dummy_time[16];
+                };
                 char        file_mime[MAX_FILE_MIME_LENGTH];
                 char        file_name[MAX_FILE_NAME_LENGTH];
+                char        file_digest[MAX_FILE_DIGEST_LENGTH];
                 char        remove_pass[MAX_REMOVE_PASS_LENGTH];
                 char        download_pass[MAX_DOWNLOAD_PASS_LENGTH];
                 char        comment[MAX_COMMENT_LENGTH];
             };
-            char            dummy[ITEM_HEADER_SIZE];
+            char            dummy_header[ITEM_HEADER_SIZE];
         };
     } header;
 
@@ -87,6 +96,7 @@ public:
     header *get_header() const;
     const char *get_file_path() const;
     const char *get_file_name() const;
+    const char *get_file_digest() const;
     const char *get_comment() const;
     const char *get_remove_pass() const;
     const char *get_download_pass() const;
@@ -105,6 +115,7 @@ private:
     static const char COMMENT_KEY[];
     static const char FILE_SIZE_KEY[];
     static const char FILE_MIME_KEY[];
+    static const char FILE_DIGEST_KEY[];
     static const char TIME_KEY[];
 
     static const apr_size_t TIME_ZONE_OFFSET;
