@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 570 2005-09-02 21:21:36Z svn $
+ * $Id: UploadItemList.h 684 2005-09-15 07:12:00Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMLIST_H
@@ -71,7 +71,7 @@ public:
     apr_size_t get_thumb_size() const;
     apr_time_t get_mtime() const;
     void update_mtime();
-    bool is_need_update() const;
+    bool is_need_update(apr_pool_t *pool) const;
     void remove(const char *file_path, const char *password);
     TemplateExecutor::variable *to_varray(apr_pool_t *pool,
                                           apr_size_t start,
@@ -130,14 +130,11 @@ private:
     void remove(item_info *info);
     void sort();
 
-    const char *create_path(apr_pool_t *tmp_pool, const char *name);
     const char *create_tmp_path(apr_pool_t *tmp_pool, const char *name,
-                                apr_file_t **tmp_file);
+                                bool is_buffered, apr_file_t **tmp_file);
 
-    const char *get_path_cache(apr_pool_t *tmp_pool);
-    const char *get_header_cache(apr_pool_t *tmp_pool);
-    const char *get_tmp_path_cache(apr_pool_t *tmp_pool, apr_file_t **cache_file);
-    const char *get_tmp_header_cache(apr_pool_t *tmp_pool, apr_file_t **cache_file);
+    const char *get_tmp_path_cache_path(apr_pool_t *tmp_pool, apr_file_t **cache_file);
+    const char *get_tmp_header_cache_path(apr_pool_t *tmp_pool, apr_file_t **cache_file);
 
     void read_cache(apr_pool_t *tmp_pool,
                     char **paths, UploadItem::header **headers, apr_size_t *number);
@@ -151,9 +148,13 @@ private:
     apr_pool_t *data_pool_;
     const char *file_dir_;
     const char *thumb_dir_;
+    const char *path_cache_path_;
+    const char *header_cache_path_;
     const apr_size_t total_number_limit_;
     const apr_uint64_t total_size_limit_;
 
+    static const char *create_path(apr_pool_t *tmp_pool, const char *dir_path, const char *file_name);
+
     UploadItemReader reader_;
 #ifdef MAKE_THUMBNAIL
     ThumbnailWriter twriter_;
