@@ -31,7 +31,8 @@
 #include "PostReader.h"
 #include "Misc.h"
 
-#include <stdio.h>
+#define APR_WANT_STDIO
+#include "apr_want.h"
 
 #ifdef DEBUG
 #include <iostream>
