@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateVariableCreator.cpp 532 2005-08-30 09:30:01Z svn $
+ * $Id: TemplateVariableCreator.cpp 682 2005-09-15 06:41:06Z svn $
  *****************************************************************************/
 
 #include "TemplateVariableCreator.h"
@@ -58,6 +58,8 @@ TemplateVariableCreator::variable *TemplateVariableCreator::create(apr_pool_t *p
                  create(pool, item->get_file_size()));
     apr_hash_set(hash, UploadItem::FILE_MIME_KEY, APR_HASH_KEY_STRING,
                  create(pool, item->get_file_mime()));
+    apr_hash_set(hash, UploadItem::FILE_DIGEST_KEY, APR_HASH_KEY_STRING,
+                 create(pool, item->get_file_digest()));
     apr_hash_set(hash, UploadItem::TIME_KEY, APR_HASH_KEY_STRING,
                  create(pool, item->get_time()));
 
