@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 563 2005-09-02 03:22:28Z svn $
+ * $Id: UploadItem.cpp 684 2005-09-15 07:12:00Z svn $
  *****************************************************************************/
 
 #include "UploadItem.h"
@@ -54,6 +54,7 @@ const char UploadItem::REMOVE_PASS_KEY[]        = "remove_pass";
 const char UploadItem::DOWNLOAD_PASS_KEY[]      = "download_pass";
 const char UploadItem::FILE_SIZE_KEY[]          = "size";
 const char UploadItem::FILE_MIME_KEY[]          = "mime";
+const char UploadItem::FILE_DIGEST_KEY[]        = "digest";
 const char UploadItem::TIME_KEY[]               = "time";
 
 const char UploadItem::TIME_FORMAT[]            = UITEM_TIME_FORMAT;
@@ -109,6 +110,11 @@ const char *UploadItem::get_file_name() const
     return header_->file_name;
 }
 
+const char *UploadItem::get_file_digest() const
+{
+    return header_->file_digest;
+}
+
 const char *UploadItem::get_comment() const
 {
     return header_->comment;
@@ -161,6 +167,7 @@ void UploadItem::dump_header(header *header)
     cerr << "file_size: "       << static_cast<unsigned int>(header->file_size) << endl;
     cerr << "file_name: "       << header->file_name        << endl;
     cerr << "file_mime: "       << header->file_mime        << endl;
+    cerr << "file_digest: "     << header->file_digest      << endl;
     cerr << "remove_pass: "     << header->remove_pass      << endl;
     cerr << "download_pass: "   << header->download_pass    << endl;
     cerr << "comment: "         << header->comment          << endl;
@@ -186,13 +193,14 @@ void print_offset(const char *name, unsigned int offset, unsigned int expected)
     cout << "    ";
     cout.width(27);
     cout.setf(ios::left, ios::adjustfield);
-    cout << name << ": ";
+    cout << name << ": \033[1;37m";
     cout.width(3);
     cout.setf(ios::right, ios::adjustfield);
-    cout << offset << endl;
+    cout << offset << "\033[0m" << endl;
 
     if (offset != expected) {
-        cerr << "Error: expected " << expected << ", but actual " << offset << endl;
+        cerr << "\033[1;31mError: expected " << expected << ", but actual " << offset << "\033[0m" << endl;
+        exit(EXIT_FAILURE);
     }
 }
 
@@ -204,34 +212,29 @@ int main(int argc, const char * const *argv)
     apr_app_initialize(&argc, &argv, NULL);
     apr_pool_create(&pool, NULL);
 
-    cout << "* Cheack the struct size"<< endl;
-    cout << "    sizeof(UploadItem::header) : ";
+    cout << "\033[1;36m* \033[0;36mCheack the struct size\033[0m" << endl;
+    cout << "    sizeof(UploadItem::header) : \033[1;37m";
     cout.width(3);
     cout.setf(ios::right, ios::adjustfield);
-    cout << sizeof(UploadItem::header) << endl;
-    cout << "    ITEM_HEADER_SIZE           : ";
+    cout << sizeof(UploadItem::header) << "\033[0m" << endl;
+    cout << "    ITEM_HEADER_SIZE           : \033[1;37m";
     cout.width(3);
     cout.setf(ios::right, ios::adjustfield);
-    cout << UploadItem::ITEM_HEADER_SIZE << endl;
+    cout << UploadItem::ITEM_HEADER_SIZE << "\033[0m" << endl;
     if (sizeof(UploadItem::header) != UploadItem::ITEM_HEADER_SIZE) {
-        cerr << "Error: sizeof(UploadItem::header) != ITEM_HEADER_SIZE" << endl;
+        cerr << "\033[1;31mError: sizeof(UploadItem::header) != ITEM_HEADER_SIZE\033[0m" << endl;
+        exit(EXIT_FAILURE);
     }
     cout << endl;
 
-    // ǡθߴͤʤ饢饤ȤϤȤ
-    // ɡȤꤢ֡
-    //
-    // ʲǤϡPentium 4 3.06GHzLinux 2.6, GCC 3.3.5 Ǥδͤ
-    // ӤƤޤ
-
-    cout << "* Check the member offset" << endl;
+    cout << "\033[1;36m* \033[0;36mCheck the member offset\033[0m" << endl;
 
     offset = 0;
 
     print_offset("identifier",
                  offsetof(UploadItem::header, identifier),
                  offset);
-    offset += (sizeof(PACKAGE_NAME)/4 + 1)*4;
+    offset += UploadItem::MAX_IDENTIFIER_LENGTH;
 
     print_offset("version",
                  offsetof(UploadItem::header, version),
@@ -241,12 +244,12 @@ int main(int argc, const char * const *argv)
     print_offset("file_size",
                  offsetof(UploadItem::header, file_size),
                  offset);
-    offset += 4;
+    offset += 16;
 
     print_offset("time",
                  offsetof(UploadItem::header, time),
                  offset);
-    offset += 8;
+    offset += 16;
 
     print_offset("file_mime",
                  offsetof(UploadItem::header, file_mime),
@@ -258,6 +261,11 @@ int main(int argc, const char * const *argv)
                  offset);
     offset += UploadItem::MAX_FILE_NAME_LENGTH;
 
+    print_offset("file_digest",
+                 offsetof(UploadItem::header, file_digest),
+                 offset);
+    offset += UploadItem::MAX_FILE_DIGEST_LENGTH;
+
     print_offset("remove_pass",
                  offsetof(UploadItem::header, remove_pass),
                  offset);
@@ -272,6 +280,9 @@ int main(int argc, const char * const *argv)
                  offsetof(UploadItem::header, comment),
                  offset);
 
+    cout << endl;
+    cout << "\033[1;34mOK. Passed All Checks!\033[0m" << endl;
+
     apr_terminate();
 
     return EXIT_SUCCESS;
