@@ -24,13 +24,17 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemCreator.cpp 682 2005-09-15 06:41:06Z svn $
+ * $Id: UploadItemCreator.cpp 699 2005-09-18 10:16:51Z svn $
  *****************************************************************************/
 
 #include "UploadItemCreator.h"
 #include "CharCodeConverter.h"
 #include "Misc.h"
 
+#ifdef DEBUG
+#include <iostream>
+#endif
+
 
 /******************************************************************************
  * public ᥽å
