@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.cpp 551 2005-09-01 07:38:16Z svn $
+ * $Id: UploadItemReader.cpp 676 2005-09-14 14:43:48Z svn $
  *****************************************************************************/
 
 #include "UploadItemReader.h"
@@ -68,15 +68,14 @@ UploadItem::header *UploadItemReader::read(const char *file_name,
         throw "åץɥե̾ǤޤǤ";
     }
 
-    if (apr_file_open(file, file_path, APR_READ|APR_BINARY|APR_SENDFILE_ENABLED,
+    if (apr_file_open(file, file_path, APR_READ|APR_BINARY|APR_BUFFERED|APR_SENDFILE_ENABLED,
                       APR_OS_DEFAULT, pool) != APR_SUCCESS) {
         throw "åץɥե򳫤ޤǤ";
     }
 
     APR_PCALLOC(header, UploadItem::header *, pool, sizeof(UploadItem::header));
 
-    size = sizeof(UploadItem::header);
-    if ((apr_file_read(*file, header, &size) != APR_SUCCESS) ||
+    if ((apr_file_read_full(*file, header, sizeof(UploadItem::header), &size) != APR_SUCCESS) ||
         (size != sizeof(UploadItem::header))) {
         throw "åץɥǡɤ߹ޤǤ";
     }
