@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 694 2005-09-17 13:54:06Z svn $
+ * $Id: UploaderConfig.cpp 696 2005-09-17 14:41:55Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -44,7 +44,7 @@
 #define DELETE(ptr) if (ptr != NULL) { delete ptr; ptr = NULL;}
 #define DESTROY(pool) if (pool != NULL) { apr_pool_destroy(pool); pool = NULL;}
 
-const apr_uint64_t UploaderConfig::TOTAL_FILE_SIZE_LIMIT= 1024*1024*1024;
+const apr_uint64_t UploaderConfig::TOTAL_FILE_SIZE_LIMIT= 1*1024*1024*1024;
 const apr_size_t UploaderConfig::TOTAL_FILE_NUMBER_LIMIT= 1000;
 const apr_size_t UploaderConfig::MAX_FORM_FILE_SIZE     = 100*1024*1024;
 const apr_size_t UploaderConfig::MAX_FORM_TEXT_SIZE     = 1024;
@@ -113,8 +113,6 @@ void UploaderConfig::init(request_rec *r)
 
     pool_ = r->server->process->pool;
 
-    // ϼΥɤ mod_uploader.cpp ֤ɡѥեޥ
-    // ͤƤ夤
     glock_ = (static_cast<sconfig *>(ap_get_module_config(r->server->module_config,
                                                           &uploader_module)))->upload_lock;
 
