@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 686 2005-09-15 10:40:49Z svn $
+ * $Id: mod_uploader.cpp 698 2005-09-17 15:05:52Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -104,7 +104,6 @@ static pprogress *get_progress(request_rec *r, apr_size_t upload_id);
 static pprogress *add_progress_list(request_rec *r, apr_size_t upload_id);
 static pprogress *get_progress_list(request_rec *r);
 
-static const char *get_client_address(request_rec *r);
 static bool is_poster_list_contain(request_rec *r, const char *address);
 static int poster_compare(const poster *a, const poster *b);
 static void add_poster_list(request_rec *r, const char *address);
@@ -314,7 +313,7 @@ int upload(request_rec *r, uconfig *config, const char *arg)
         return HTTP_NO_CONTENT;
     }
 
-    address = get_client_address(r);
+    address = r->connection->remote_ip;
     if (is_poster_list_contain(r, address)) {
         return error(r, config,
                      apr_psprintf(r->pool, "%" APR_SIZE_T_FMT  " ô֤ϺƤǤޤ",
@@ -922,15 +921,6 @@ pprogress *get_progress_list(request_rec *r)
                                                        &uploader_module))->progress_list;
 }
 
-const char *get_client_address(request_rec *r)
-{
-    char *address = "";
-
-    apr_sockaddr_ip_get(&address, r->connection->remote_addr);
-
-    return address;
-}
-
 bool is_poster_list_contain(request_rec *r, const char *address)
 {
     poster *poster_list;
@@ -1368,7 +1358,7 @@ static const char *set_total_file_size_limit(cmd_parms *parms, void *mconfig, ch
 {
     uconfig *config = static_cast<uconfig *>(mconfig);
 
-    config->total_file_size_limit = atoi(arg) * 1024;
+    config->total_file_size_limit = atol(arg) * 1024;
 
     return NULL;
 }
